# WizWalker

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Wizard101 scripting library

## Installation
`pip install wizwalker`

## Documentation
you can find the documentation [here](https://starrfox.github.io/wizwalker/)

## Discord
you can join the offical discord [here](https://discord.gg/JHrdCNK)

## Just
this package uses [just](https://github.com/casey/just) for command running
```shell
just cli          # start wiz instance and then start debug cli
just docs         # build docs
just install      # install enviroment
just publish TYPE # publish a major, minor, or patch version
```

## Console commands
```shell
wizwalker           # Runs the wizwalker cli
wizwalker start-wiz # start wizard101 instances
wizwalker wad       # edit and extract wizard101 wad files
```
